@@ -15,6 +15,13 @@ from .exec import (
     select_one,
     query,
     query_one,
+    do_execute,
+    do_save_sql,
+    do_get,
+    do_select,
+    do_select_one,
+    do_query,
+    do_query_one,
     get_connection
 )
 from .support import DBError
