@@ -1,11 +1,10 @@
 import functools
 from . import sql_support
 from .engine import Engine
-from .init_import import import_driver
+from .init_import import import_driver, get_engine
 from .log_support import logger, insert_log, save_log, get_log, sql_log
 from .support import DBCtx, ConnectionCtx, Dict, MultiColumnsError, TransactionCtx, try_commit, DBError, DB_LOCK
-from .constant import MYSQL_CONNECTOR_DRIVER, SQLITE, PARAM_DRIVER, PARAM_SHOW_SQL, PARAM_TRANS_PLACEHOLDER, PARAM_DEBUG, PARAM_POOL_SIZE, PARAM_PORT,\
-    MYSQL, POSTGRESQL, UNKNOW, MYSQL_PORT, POSTGRESQL_PORT
+from .constant import MYSQL_CONNECTOR_DRIVER, SQLITE, PARAM_DRIVER, PARAM_SHOW_SQL, PARAM_TRANS_PLACEHOLDER, PARAM_DEBUG, PARAM_POOL_SIZE
 
 _DB_CTX = None
 
@@ -37,14 +36,7 @@ def init_db(*args, **kwargs):
     show_sql = kwargs.pop(PARAM_SHOW_SQL) if PARAM_SHOW_SQL in kwargs else False
     trans_placeholder = kwargs.pop(PARAM_TRANS_PLACEHOLDER) if PARAM_TRANS_PLACEHOLDER in kwargs else True
 
-    curr_engine = Engine.current_engine()
-    if driver is None and (curr_engine is None or curr_engine == UNKNOW) and PARAM_PORT in kwargs:
-        port = kwargs[PARAM_PORT]
-        if port == MYSQL_PORT:
-            curr_engine = MYSQL
-        elif port == POSTGRESQL_PORT:
-            curr_engine = POSTGRESQL
-
+    curr_engine = get_engine(driver, *args, **kwargs)
     engine, driver, creator = import_driver(driver, curr_engine)
     prepared = MYSQL_CONNECTOR_DRIVER == driver
     if PARAM_DEBUG in kwargs and kwargs.pop(PARAM_DEBUG):
@@ -136,24 +128,13 @@ def with_transaction(func):
     return _wrapper
 
 
-@with_connection
-def execute(sql: str, *args):
+def execute(sql: str, *args, **kwargs):
     """
     Execute sql return effect rowcount
     sql: insert into person(name, age) values(?, ?)  -->  args: ('张三', 20)
     """
-    global _DB_CTX
-    cursor = None
-    sql = Engine.before_execute_intf('execute', sql.strip(), *args)
-    try:
-        cursor = _DB_CTX.connection.cursor()
-        cursor.execute(sql, args)
-        effect_rowcount = cursor.rowcount
-        try_commit(_DB_CTX)
-        return effect_rowcount
-    finally:
-        if cursor:
-            cursor.close()
+    sql, args = try_mapping('sqlexec.execute', sql, *args, **kwargs)
+    return do_execute(sql, *args)
 
 
 def insert(table: str, **kwargs):
@@ -238,7 +219,7 @@ def get(sql: str, *args, **kwargs):
     MultiColumnsError: Expect only one column.
     sql: SELECT count(1) FROM person WHERE name=? and age=? limit 1  -->  args: ('张三', 20)
     """
-    sql, args = _try_mapping('sqlexec.get', sql, *args, **kwargs)
+    sql, args = try_mapping('sqlexec.get', sql, *args, **kwargs)
     return do_get(sql, *args)
 
 
@@ -247,7 +228,7 @@ def select(sql: str, *args, **kwargs):
     execute select SQL and return unique result or list results(tuple).
     sql: SELECT * FROM person WHERE name=? and age=?  -->  args: ('张三', 20)
     """
-    sql, args = _try_mapping('sqlexec.select', sql, *args, **kwargs)
+    sql, args = try_mapping('sqlexec.select', sql, *args, **kwargs)
     return do_select(sql, *args)
 
 
@@ -256,7 +237,7 @@ def select_one(sql: str, *args, **kwargs):
     Execute select SQL and return unique result(tuple), SQL contain 'limit'.
     sql: SELECT * FROM person WHERE name=? and age=? limit 1  -->  args: ('张三', 20)
     """
-    sql, args = _try_mapping('sqlexec.select_one', sql, *args, **kwargs)
+    sql, args = try_mapping('sqlexec.select_one', sql, *args, **kwargs)
     return do_select_one(sql, *args)
 
 
@@ -265,7 +246,7 @@ def query(sql: str, *args, **kwargs):
     Execute select SQL and return list results(dict).
     sql: SELECT * FROM person WHERE name=? and age=?  -->  args: ('张三', 20)
     """
-    sql, args = _try_mapping('sqlexec.query', sql, *args, **kwargs)
+    sql, args = try_mapping('sqlexec.query', sql, *args, **kwargs)
     return do_query(sql, *args)
 
 
@@ -274,7 +255,7 @@ def query_one(sql: str, *args, **kwargs):
     execute select SQL and return unique result(dict), SQL contain 'limit'.
     sql: SELECT * FROM person WHERE name=? and age=? limit 1  -->  args: ('张三', 20)
     """
-    sql, args = _try_mapping('sqlexec.query_one', sql, *args, **kwargs)
+    sql, args = try_mapping('sqlexec.query_one', sql, *args, **kwargs)
     return do_query_one(sql, *args)
 
 
@@ -329,8 +310,8 @@ def do_get(sql: str, *args):
     MultiColumnsError: Expect only one column.
     sql: SELECT count(1) FROM person WHERE name=? and age=? limit 1  -->  args: ('张三', 20)
     """
-    get_log('get', sql, *args)
-    result = select_one(sql, *args)
+    get_log('do_get', sql, *args)
+    result = do_select_one(sql, *args)
     if result:
         if len(result) == 1:
             return result[0]
@@ -427,6 +408,6 @@ def get_connection():
     return _DB_CTX.connection
 
 
-def _try_mapping(function, sql, *args, **kwargs):
+def try_mapping(function, sql, *args, **kwargs):
     sql_log(function, sql, *args, **kwargs)
     return sql_support.get_mapping_sql_args(sql, *args, **kwargs)
