@@ -1,7 +1,8 @@
 import importlib
+from .engine import Engine
 from .support import DBError
 from .log_support import logger
-from .constant import DRIVERS, UNKNOW
+from .constant import DRIVERS, PARAM_PORT, MYSQL, POSTGRESQL, UNKNOW, MYSQL_PORT, POSTGRESQL_PORT, SQLITE
 
 
 def import_driver(driver, curr_engine):
@@ -30,3 +31,22 @@ def do_import(driver, Engine):
         return importlib.import_module(driver)
     except ModuleNotFoundError:
         raise DBError(f"Import {Engine} driver '{driver}' failed, please sure it was installed or change other driver.")
+
+
+def get_engine(driver: str, *args, **kwargs):
+    curr_engine = Engine.current_engine()
+    if driver is None and (curr_engine is None or curr_engine == UNKNOW):
+        if args and isinstance(args[0], str):
+            if 'mysql://' in args[0]:
+                curr_engine = MYSQL
+            elif 'postgres://' in args[0]:
+                curr_engine = POSTGRESQL
+            elif '://' not in args[0]:
+                curr_engine = SQLITE
+        elif  PARAM_PORT in kwargs:
+            port = kwargs[PARAM_PORT]
+            if port == MYSQL_PORT:
+                curr_engine = MYSQL
+            elif port == POSTGRESQL_PORT:
+                curr_engine = POSTGRESQL
+    return curr_engine
