@@ -1,6 +1,7 @@
 import re
 from .engine import Engine
 from typing import Sequence
+from .support import DBError
 from functools import lru_cache
 from .constant import CACHE_SIZE, NAMED_REGEX
 
@@ -10,6 +11,7 @@ def insert_sql_args(table: str, **kwargs):
     return sql, args
 
 
+
 def get_batch_args(*args):
     return args[0] if isinstance(args, tuple) and len(args) == 1 and isinstance(args[0], Sequence) else args
 
@@ -36,3 +38,27 @@ def get_named_sql(sql: str):
 
 def get_named_args(sql: str, **kwargs):
     return [kwargs[r[1:]] for r in re.findall(NAMED_REGEX, sql)]
+
+
+def get_named_sql_args(sql: str, **kwargs):
+    args = get_named_args(sql, **kwargs)
+    return get_named_sql(sql), args
+
+
+def is_mapping(sql: str):
+    return ':' in sql
+
+
+def is_placeholder(sql: str):
+    return '?' in sql
+
+
+def get_mapping_sql_args(sql: str, *args, **kwargs):
+    if is_mapping(sql):
+        assert kwargs, "Named mapping SQL expect '**kwargs' should not be empty."
+        return get_named_sql_args(sql, **kwargs)
+
+    if is_placeholder(sql) and not args:
+        raise DBError("Placeholder sql expect '*args' should not be empty.")
+
+    return sql, args
